@@ -4,14 +4,14 @@ use warnings;
 use Exporter 'import';
 our @EXPORT = 'kensiro';
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use 5.008001;
 
 sub kensiro {
     my $src = shift;
 
-    my $dst = unpack("B8",  pack("C", $src));
+    my $dst = reverse(unpack("b32",  pack("L", $src)));
     $dst =~ s/^0*(.+)/$1/;
     $dst =~ s/0/た/g;
     $dst =~ s/1/あ/g;
